@@ -27,10 +27,11 @@ network calls. Pymongo 3.0 and greater are the currently supported versions.
 from ...utils.importlib import require_modules
 
 
-required_modules = ['pymongo']
+required_modules = ["pymongo"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
         from .patch import patch
         from .patch import trace_mongo_client
-        __all__ = ['trace_mongo_client', 'patch']
+
+        __all__ = ["trace_mongo_client", "patch"]
